@@ -75,7 +75,7 @@ class OpenCogSchemeLink
 		public Boolean FNCallback(FeatureNode fn)
 		{
 			str +=
-				"(EvaluationLink\n" + 
+				"(EvaluationLink (stv 1.0 1.0)\n" + 
 				"   (LinkGrammarRelationshipNode \"" +
 				fn.get("LAB").getValue() + "\")\n" +
 				"   (ListLink\n" +
