@@ -15,9 +15,11 @@
  */
 package relex.output;
 
-import relex.feature.RelationCallback;
-import relex.feature.FeatureForeach;
+import java.util.HashMap;
+
 import relex.feature.FeatureNode;
+import relex.feature.RelationCallback;
+import relex.ParsedSentence;
 
 /**
  * Implements a very simple, direct printout of the 
@@ -38,11 +40,17 @@ public class SimpleView
 	 *   DEFINITE-FLAG(ball, T)
 	 *   noun_number(ball, singular)
 	 */
-	public static String printRelations(FeatureNode root)
+	public static String printRelations(ParsedSentence parse)
+	{
+		return printRelations(parse, null);
+	}
+	public static String printRelations(ParsedSentence parse,
+	                                    HashMap<FeatureNode,String> map)
 	{
 		Visit v = new Visit();
+		v.id_map = map;
 		v.str = "";
-		FeatureForeach.foreach(root, v);
+		parse.foreach(v);
 		return v.str;
 	}
 
@@ -58,17 +66,26 @@ public class SimpleView
 	 *   definite(ball)
 	 *   singular(ball)
 	 */
-	public static String printRelationsAlt(FeatureNode root)
+	public static String printRelationsAlt(ParsedSentence parse)
+	{
+		return printRelationsAlt(parse, null);
+	}
+	public static String printRelationsAlt(ParsedSentence parse,
+	                                    HashMap<FeatureNode,String> map)
 	{
 		Visit v = new Visit();
+		v.id_map = map;
 		v.unaryStyle = true;
 		v.str = "";
-		FeatureForeach.foreach(root, v);
+		parse.foreach(v);
 		return v.str;
 	}
 
 	private static class Visit implements RelationCallback
 	{
+		// Map associating a feature-node to a unique ID string.
+		public HashMap<FeatureNode,String> id_map = null;
+
 		public Boolean unaryStyle = false;
 		public String str;
 		public Boolean BinaryHeadCB(FeatureNode node) { return false; }
@@ -86,6 +103,11 @@ public class SimpleView
 			}
 			String tgtName = tgt.getValue();
 
+			if (id_map != null)
+			{
+				srcName = id_map.get(srcNode);
+				tgtName = id_map.get(tgtNode);
+			}
 			str += relName + "(" + srcName + ", " + tgtName + ")\n";
 
 			return false;
@@ -98,6 +120,10 @@ public class SimpleView
 			String value = attr.getValue();
 			String srcName = srcNode.get("name").getValue();
 
+			if (id_map != null)
+			{
+				srcName = id_map.get(srcNode);
+			}
 			if (unaryStyle)
 			{
 				if (attrName.endsWith("-FLAG"))
